@@ -14,7 +14,6 @@
 #   [Email](mailto:hello@blockworks.foundation)
 
 import argparse
-import datetime
 import copy
 import logging
 import os
@@ -64,7 +63,8 @@ class ContextBuilder:
         parser.add_argument("--name", type=str, default="Mango Explorer",
                             help="Name of the program (used in reports and alerts)")
         parser.add_argument("--cluster-name", type=str, default=None, help="Solana RPC cluster name")
-        parser.add_argument("--cluster-url", type=str, default=None, help="Solana RPC cluster URL")
+        parser.add_argument("--cluster-url", type=str, action="append", default=[],
+                            help="Solana RPC cluster URL (can be specified multiple times to provide failover when one errors)")
         parser.add_argument("--group-name", type=str, default=None, help="Mango group name")
         parser.add_argument("--group-address", type=PublicKey, default=None, help="Mango group address")
         parser.add_argument("--mango-program-address", type=PublicKey, default=None, help="Mango program address")
@@ -72,11 +72,14 @@ class ContextBuilder:
         parser.add_argument("--skip-preflight", default=False, action="store_true", help="Skip pre-flight checks")
         parser.add_argument("--commitment", type=str, default=None,
                             help="Commitment to use when sending transactions (can be 'finalized', 'confirmed' or 'processed')")
-        parser.add_argument("--blockhash-commitment", type=str, default=None,
-                            help="Commitment to use specifically when fetching recent blockhash (can be 'finalized', 'confirmed' or 'processed')")
         parser.add_argument("--encoding", type=str, default=None,
                             help="Encoding to request when receiving data from Solana (options are 'base58' (slow), 'base64', 'base64+zstd', or 'jsonParsed')")
-        parser.add_argument("--blockhash-cache-duration", type=int, help="How long to cache 'recent' blockhashes")
+        parser.add_argument("--blockhash-cache-duration", type=int,
+                            help="How long (in seconds) to cache 'recent' blockhashes")
+        parser.add_argument("--stale-data-pause-before-retry", type=Decimal,
+                            help="How long (in seconds, e.g. 0.1) to pause after retrieving stale data before retrying")
+        parser.add_argument("--stale-data-maximum-retries", type=int,
+                            help="How many times to retry fetching data after being given stale data before giving up")
         parser.add_argument("--gma-chunk-size", type=Decimal, default=None,
                             help="Maximum number of addresses to send in a single call to getMultipleAccounts()")
         parser.add_argument("--gma-chunk-pause", type=Decimal, default=None,
@@ -95,23 +98,35 @@ class ContextBuilder:
     def from_command_line_parameters(args: argparse.Namespace) -> Context:
         name: typing.Optional[str] = args.name
         cluster_name: typing.Optional[str] = args.cluster_name
-        cluster_url: typing.Optional[str] = args.cluster_url
+        cluster_urls: typing.Optional[typing.Sequence[str]] = args.cluster_url
         group_name: typing.Optional[str] = args.group_name
         group_address: typing.Optional[PublicKey] = args.group_address
         mango_program_address: typing.Optional[PublicKey] = args.mango_program_address
         serum_program_address: typing.Optional[PublicKey] = args.serum_program_address
         skip_preflight: bool = bool(args.skip_preflight)
         commitment: typing.Optional[str] = args.commitment
-        blockhash_commitment: typing.Optional[str] = args.blockhash_commitment
         encoding: typing.Optional[str] = args.encoding
-        blockhash_cache_duration: typing.Optional[datetime.timedelta] = datetime.timedelta(
-            seconds=args.blockhash_cache_duration) if args.blockhash_cache_duration is not None else None
+        blockhash_cache_duration: typing.Optional[int] = args.blockhash_cache_duration
+        stale_data_pause_before_retry: typing.Optional[Decimal] = args.stale_data_pause_before_retry
+        stale_data_maximum_retries: typing.Optional[int] = args.stale_data_maximum_retries
         gma_chunk_size: typing.Optional[Decimal] = args.gma_chunk_size
         gma_chunk_pause: typing.Optional[Decimal] = args.gma_chunk_pause
         token_filename: str = args.token_data_file
 
-        context: Context = ContextBuilder.build(name, cluster_name, cluster_url, skip_preflight, commitment, blockhash_commitment, encoding, blockhash_cache_duration,
-                                                group_name, group_address, mango_program_address, serum_program_address, gma_chunk_size, gma_chunk_pause, token_filename)
+        # Do this here so build() only ever has to handle the sequence of retry times. (It gets messy
+        # passing around the sequnce *plus* the data to reconstruct it for build().)
+        actual_maximum_stale_data_pauses: int = stale_data_maximum_retries or 20
+        actual_stale_data_pauses_before_retry: typing.Sequence[float] = []
+        if stale_data_pause_before_retry is not None:
+            actual_stale_data_pauses_before_retry = [
+                float(stale_data_pause_before_retry)] * actual_maximum_stale_data_pauses
+
+        context: Context = ContextBuilder.build(name, cluster_name, cluster_urls, skip_preflight, commitment,
+                                                encoding, blockhash_cache_duration,
+                                                actual_stale_data_pauses_before_retry,
+                                                group_name, group_address, mango_program_address,
+                                                serum_program_address, gma_chunk_size, gma_chunk_pause,
+                                                token_filename)
         logging.debug(f"{context}")
 
         return context
@@ -122,11 +137,12 @@ class ContextBuilder:
 
     @staticmethod
     def from_group_name(context: Context, group_name: str) -> Context:
-        return ContextBuilder.build(context.name, context.client.cluster_name, context.client.cluster_url,
+        return ContextBuilder.build(context.name, context.client.cluster_name, context.client.cluster_urls,
                                     context.client.skip_preflight, context.client.commitment,
-                                    context.client.blockhash_commitment, context.client.encoding,
-                                    context.client.compatible_client.blockhash_cache_duration,
-                                    group_name, None, None, None, context.gma_chunk_size, context.gma_chunk_pause,
+                                    context.client.encoding, context.client.blockhash_cache_duration,
+                                    context.client.stale_data_pauses_before_retry,
+                                    group_name, None, None, None,
+                                    context.gma_chunk_size, context.gma_chunk_pause,
                                     SPLTokenLookup.DefaultDataFilepath)
 
     @staticmethod
@@ -136,12 +152,12 @@ class ContextBuilder:
         fresh_context = copy.copy(context)
         fresh_context.client = BetterClient.from_configuration(context.name,
                                                                cluster_name,
-                                                               cluster_url,
+                                                               [cluster_url],
                                                                context.client.commitment,
-                                                               context.client.blockhash_commitment,
                                                                context.client.skip_preflight,
                                                                context.client.encoding,
-                                                               context.client.compatible_client.blockhash_cache_duration,
+                                                               context.client.blockhash_cache_duration,
+                                                               context.client.stale_data_pauses_before_retry,
                                                                context.client.instruction_reporter)
 
         return fresh_context
@@ -153,26 +169,27 @@ class ContextBuilder:
         fresh_context = copy.copy(context)
         fresh_context.client = BetterClient.from_configuration(context.name,
                                                                cluster_name,
-                                                               cluster_url,
+                                                               [cluster_url],
                                                                context.client.commitment,
-                                                               context.client.blockhash_commitment,
                                                                context.client.skip_preflight,
                                                                context.client.encoding,
-                                                               context.client.compatible_client.blockhash_cache_duration,
+                                                               context.client.blockhash_cache_duration,
+                                                               context.client.stale_data_pauses_before_retry,
                                                                context.client.instruction_reporter)
 
         return fresh_context
 
     @staticmethod
     def build(name: typing.Optional[str] = None, cluster_name: typing.Optional[str] = None,
-              cluster_url: typing.Optional[str] = None, skip_preflight: bool = False,
-              commitment: typing.Optional[str] = None, blockhash_commitment: typing.Optional[str] = None,
-              encoding: typing.Optional[str] = None, blockhash_cache_duration: typing.Optional[datetime.timedelta] = None,
+              cluster_urls: typing.Optional[typing.Sequence[str]] = None, skip_preflight: bool = False,
+              commitment: typing.Optional[str] = None, encoding: typing.Optional[str] = None,
+              blockhash_cache_duration: typing.Optional[int] = None,
+              stale_data_pauses_before_retry: typing.Optional[typing.Sequence[float]] = None,
               group_name: typing.Optional[str] = None, group_address: typing.Optional[PublicKey] = None,
               program_address: typing.Optional[PublicKey] = None, serum_program_address: typing.Optional[PublicKey] = None,
               gma_chunk_size: typing.Optional[Decimal] = None, gma_chunk_pause: typing.Optional[Decimal] = None,
               token_filename: str = SPLTokenLookup.DefaultDataFilepath) -> "Context":
-        def public_key_or_none(address: typing.Optional[str]) -> typing.Optional[PublicKey]:
+        def __public_key_or_none(address: typing.Optional[str]) -> typing.Optional[PublicKey]:
             if address is not None and address != "":
                 return PublicKey(address)
             return None
@@ -189,12 +206,18 @@ class ContextBuilder:
                 break
 
         actual_commitment: str = commitment or "processed"
-        actual_blockhash_commitment: str = blockhash_commitment or commitment or "processed"
         actual_encoding: str = encoding or "base64"
-        actual_blockhash_cache_duration: datetime.timedelta = blockhash_cache_duration or datetime.timedelta(seconds=0)
+        actual_blockhash_cache_duration: int = blockhash_cache_duration or 0
+        actual_stale_data_pauses_before_retry: typing.Sequence[float] = stale_data_pauses_before_retry or []
+
+        actual_cluster_urls: typing.Optional[typing.Sequence[str]] = cluster_urls
+        if actual_cluster_urls is None or len(actual_cluster_urls) == 0:
+            cluster_url_from_environment: typing.Optional[str] = os.environ.get("CLUSTER_URL")
+            if cluster_url_from_environment is not None and cluster_url_from_environment != "":
+                actual_cluster_urls = [cluster_url_from_environment]
+            else:
+                actual_cluster_urls = [MangoConstants["cluster_urls"][actual_cluster]]
 
-        actual_cluster_url: str = cluster_url or os.environ.get(
-            "CLUSTER_URL") or MangoConstants["cluster_urls"][actual_cluster]
         actual_skip_preflight: bool = skip_preflight
         actual_group_name: str = group_name or os.environ.get("GROUP_NAME") or default_group_data["name"]
 
@@ -206,11 +229,11 @@ class ContextBuilder:
         if found_group_data is None:
             raise Exception(f"Could not find group named '{actual_group_name}' in cluster '{actual_cluster}'.")
 
-        actual_group_address: PublicKey = group_address or public_key_or_none(os.environ.get(
+        actual_group_address: PublicKey = group_address or __public_key_or_none(os.environ.get(
             "GROUP_ADDRESS")) or PublicKey(found_group_data["publicKey"])
-        actual_program_address: PublicKey = program_address or public_key_or_none(os.environ.get(
+        actual_program_address: PublicKey = program_address or __public_key_or_none(os.environ.get(
             "MANGO_PROGRAM_ADDRESS")) or PublicKey(found_group_data["mangoProgramId"])
-        actual_serum_program_address: PublicKey = serum_program_address or public_key_or_none(os.environ.get(
+        actual_serum_program_address: PublicKey = serum_program_address or __public_key_or_none(os.environ.get(
             "SERUM_PROGRAM_ADDRESS")) or PublicKey(found_group_data["serumProgramId"])
 
         actual_gma_chunk_size: Decimal = gma_chunk_size or Decimal(100)
@@ -245,4 +268,4 @@ class ContextBuilder:
             all_market_lookup = CompoundMarketLookup([ids_json_market_lookup, devnet_serum_market_lookup])
         market_lookup: MarketLookup = all_market_lookup
 
-        return Context(actual_name, actual_cluster, actual_cluster_url, actual_skip_preflight, actual_commitment, actual_blockhash_commitment, actual_encoding, actual_blockhash_cache_duration, actual_program_address, actual_serum_program_address, actual_group_name, actual_group_address, actual_gma_chunk_size, actual_gma_chunk_pause, instrument_lookup, market_lookup)
+        return Context(actual_name, actual_cluster, actual_cluster_urls, actual_skip_preflight, actual_commitment, actual_encoding, actual_blockhash_cache_duration, actual_stale_data_pauses_before_retry, actual_program_address, actual_serum_program_address, actual_group_name, actual_group_address, actual_gma_chunk_size, actual_gma_chunk_pause, instrument_lookup, market_lookup)
