@@ -74,14 +74,26 @@ class OrderType(enum.Enum):
 
     @staticmethod
     def from_value(value: Decimal) -> "OrderType":
-        converted: pyserum.enums.OrderType = pyserum.enums.OrderType(int(value))
-        if converted == pyserum.enums.OrderType.IOC:
-            return OrderType.IOC
-        elif converted == pyserum.enums.OrderType.POST_ONLY:
-            return OrderType.POST_ONLY
-        elif converted == pyserum.enums.OrderType.LIMIT:
+        # From: https://github.com/blockworks-foundation/mango-v3/blob/0c4d26e3e32821d871c5e5986edafbf694a44137/program/src/matching.rs#L212
+        # pub enum OrderType {
+        #     Limit = 0,
+        #     ImmediateOrCancel = 1,
+        #     PostOnly = 2,
+        #     Market = 3,
+        #     PostOnlySlide = 4, // ***
+        # }
+        if value == 0:
             return OrderType.LIMIT
-        return OrderType.UNKNOWN
+        elif value == 1:
+            return OrderType.IOC
+        elif value == 2:
+            return OrderType.POST_ONLY
+        elif value == 3:
+            return OrderType.MARKET
+        elif value == 4:
+            return OrderType.POST_ONLY_SLIDE
+
+        return OrderType.LIMIT
 
     def to_serum(self) -> pyserum.enums.OrderType:
         if self == OrderType.IOC:
@@ -200,7 +212,7 @@ class Order(typing.NamedTuple):
         order_type: str = ""
         if self.order_type != OrderType.UNKNOWN:
             order_type = f" {self.order_type}"
-        return f"« 𝙾𝚛𝚍𝚎𝚛 {owner}{self.side} for {self.quantity:,.8f} at {self.price:.8f} [ID: {self.id} / {self.client_id}]{order_type} »"
+        return f"« Order {owner}{self.side} for {self.quantity:,.8f} at {self.price:.8f} [ID: {self.id} / {self.client_id}]{order_type} »"
 
     def __repr__(self) -> str:
         return f"{self}"
@@ -312,7 +324,7 @@ class OrderBook:
         if self.spread != 0 and self.top_bid is not None:
             spread_percentage = (self.spread / self.top_bid.price)
             spread_description = f"{self.spread:,.8f}, {spread_percentage:,.3%}"
-        return f"« 𝙾𝚛𝚍𝚎𝚛𝙱𝚘𝚘𝚔 {self.symbol} [spread: {spread_description}]\n\t{text}\n»"
+        return f"« OrderBook {self.symbol} [spread: {spread_description}]\n\t{text}\n»"
 
     def __repr__(self) -> str:
         return f"{self}"
